@@ -23,7 +23,12 @@ import omas
 from omas import ODS
 from omfit_classes.omfit_base import OMFITtmp, OMFITmodule, OMFITtree
 from omfit_classes.omfit_json import OMFITjson, OMFITsettings, SettingsName
-from omfit_classes.omfit_omas_utils import setup_hardware_overlay_cx, add_hardware_to_ods, omas_eq1d_pretty_name
+from omfit_classes.omfit_omas_utils import (
+    setup_hardware_overlay_cx,
+    add_hardware_to_ods,
+    omas_eq1d_pretty_name,
+    ensure_consistent_experiment_info,
+)
 from omfit_classes.omfit_formatter import omfit_formatter
 from omfit_classes.utils_fusion import is_device
 from omfit_classes.omfit_mds import translate_MDSserver
