@@ -874,6 +874,8 @@ def edit_github_comment(
     # Deal with different line break conventions; \r\n moves to the start of the line and then breaks, \n just breaks.
     # On Unix, \n should be used. \r\n is used by Windows and apparently web stuff like GitHub. It's only important
     # here because it breaks the str comparison. GitHub will convert \n into whatever it needs.
+    if old_content is None:
+        old_content = ''
     old_content = old_content.replace('\r\n', '\n')
 
     # Define content to post
