@@ -700,14 +700,17 @@ class OMFITnimrod(SortedDict, OMFITobject):
             self['r'].append(alld[k][:, 0])
             self['z'].append(alld[k][:, 1])
 
-    def _plot_grid(self):
+    def _plot_grid(self, alpha=1, linewidth=1, linestyle='-', color=None):
         """
         Default plot for grid.bin files
         """
         pyplot.gca().set_aspect('equal')
-        colors = color_cycle(len(self['r']))
+        if color is None:
+            colors = color_cycle(len(self['r']))
+        else:
+            colors = len(self['r']) * [color]
         for k in range(len(colors)):
-            pyplot.plot(self['r'][k], self['z'][k], color=colors[k])
+            pyplot.plot(self['r'][k], self['z'][k], color=colors[k], linewidth=linewidth, linestyle=linestyle, alpha=alpha)
         pyplot.xlabel('R [m]')
         pyplot.ylabel('Z [m]')
 
@@ -944,7 +947,7 @@ class OMFITnimrod(SortedDict, OMFITobject):
         else:
             self['data'] = self._read_table()
 
-    def plot(self, slice=0, phase=0, nlevels=21):
+    def plot(self, slice=0, phase=0, nlevels=21, linewidth=1, linestyle='-', color=None, alpha=1):
         """
         Default plot of energy.bin, discharge.bin, contour.bin and grid.bin files
 
@@ -971,7 +974,7 @@ class OMFITnimrod(SortedDict, OMFITobject):
         elif 'conrz' in os.path.split(self.filename)[1]:
             self._plot_contour(slice=slice, phase=phase, nlevels=nlevels)
         elif 'grid' in os.path.split(self.filename)[1]:
-            self._plot_grid()
+            self._plot_grid(linewidth=linewidth, linestyle=linestyle, alpha=alpha, color=color)
         elif 'xy_slice' in os.path.split(self.filename)[1]:
             self._plot_xy_slice(nlevels=nlevels)
         elif 'xyrz' in os.path.split(self.filename)[1]:
