@@ -691,6 +691,7 @@ class OMFITpFile(SortedDict, OMFITascii):
             ('rotation_frequency_tor_sonic', 'omgeb', sign_Ip * 1e3),  # sign_Ip accounts for abs(Bp) in pFile definition
             ('pressure_perpendicular', 'ptot', 1e3 / 3.0),
             ('pressure_parallel', 'ptot', 1e3 / 3.0),
+            ('e_field.radial', 'er', 1e3),
             ('electrons.density_thermal', 'ne', 1e20),
             ('electrons.temperature', 'te', 1e3),
             ('electrons.rotation.perpendicular', 'omevb', 1e3),
@@ -741,6 +742,8 @@ class OMFITpFile(SortedDict, OMFITascii):
             (f'ion.{bk}.density_fast', 'nb', 1e20),
             (f'ion.{bk}.pressure_fast_perpendicular', 'pb', 1e3 / 3.0),
             (f'ion.{bk}.pressure_fast_parallel', 'pb', 1e3 / 3.0),
+            (f'ion.{mk}.velocity.toroidal', 'vtor1', 1e3),
+            (f'ion.{mk}.velocity.poloidal', 'vpol1', 1e3),
         ]
 
         if 'N Z A' in self:
