@@ -38,6 +38,7 @@ _RDBserverDict = {
     'EAST': 'east_database',
     'east': 'east_database',
     'nstx': 'nstxrdb',
+    'ignition': 'loki',
 }
 
 
@@ -103,6 +104,7 @@ def _read_rdb_password_from_file(server=None, filename=None):
         'east_database': ['east_database.sybase_login'],
         'energy': ['ENERGY.sybase_login'],
         'nstxrdb': ['nstxlogs.sybase_login'],
+        'loki': ['loki.sybase_login'],
     }.get(translate_RDBserver(server), [''])
     files = [filename] if filename is not None else files
 
