@@ -392,7 +392,11 @@ def traverse(
         ):
             string_out += string + '\n'
         # do not go deeper if skipDynaLoad and the file has not been loaded
-        if skipDynaLoad and hasattr(self[kid], 'dynaLoad') and self[kid].dynaLoad:
+        try:
+            if skipDynaLoad and hasattr(self[kid], 'dynaLoad') and self[kid].dynaLoad:
+                continue
+        except RecursionError:
+            printe(f'Error recursing {string}')
             continue
         # go deeper
         if noSubmodules:
