@@ -59,7 +59,7 @@ class OMFITobject(object):
                 raise OMFITexception("No such file or directory: '" + filename + "'")
 
         # set filename attributes
-        filename = os.path.abspath(filename)
+        filename = os.path.realpath(os.path.expandvars(os.path.expanduser(filename)))
         self.originalFilename = filename
         self.filename = filename
         self.link = filename
